#!/usr/bin/env bash

# author: Almut Luetge

########################################################
############## Method Utils Functions #################
########################################################


{ # try
    source src/utils/bash/dataset_utils.sh
} || { 
    echo "Warning, utils/bash/dataset_utils.sh does not exist and may be required for some functions."
}



{ # try
    source src/config.sh
} || { 
    echo "Warning, src/config.sh does not exist and may be required for some functions."
}


## -------------------------------------------------- ##
## ------ Functions to access parameter space  -------##
## -------------------------------------------------- ##

# ---------------- get_all_param_combs---------------- #

# DESCRIPTION: Function to generate a list of all valid parameter combinations for a method.
# DETAILS:     Uses the omnibenchmark parameter dataset and filters for those parameter valid for a specific method.
# INPUT1:      Name of the dataset with the respective parameter json of that omnibenchmark
# INPUT2:      Name of the parameter array that defines the valid parameter for a method (default PARAM_AR as defined in src/config.sh)
# OUTPUT:      List with all valid parameter combinations of a specific method

function get_all_param_combs (){
    
    local param_key=$1
    local -n param_ar=${2:-PARAM_AR}
    local param_name=`query_datasets_by_keyword $param_key name` 
    local param_json=${3:-`renku dataset ls-files ${param_name} -c path | grep json`}
    local var_all=()
    local param_keys=(`echo ${!param_ar[@]}`)
    
    for param in ${!param_ar[@]}; do
    
        if [[ $param == $param_keys ]];
        then
            var_print=$(cat ${param_json} | jq -r ".${param} | .[]" |  sed 's/ /\'',\'$param\'=\''/g' | sed 's/^/\''\'$param\'=\''/')
        else
            var_print=$(cat ${param_json} | jq -r ".${param} | .[]" | sed 's/ /\'',_\'$param\'=\''/g' | sed 's/^/\''_\'$param\'=\''/')
        fi
        var_all+=$(echo "{${var_print}}")
    
    done

    eval `echo echo ${var_all[@]}`
}



function generate_param_json (){
    # input parameter combinations as from get_all_param_combs
    # input json keys for workflow description json
    # output workflow description json to use with renku workflow loop
    
    local param_all="$@"
    local json_key1="parameter"
    local json_key2="looped_parameters"
    local json_key3="steps"
       
    key2_val=$(echo {\"$param_all\"} | sed "s/ /\" }, { \"/g" | sed "s/=/\": \"/g" | sed "s/_/\", \"/g") 
    
    echo -e "{ \"$json_key1\": [], \"$json_key2\": [$key2_val], \"$json_key3\": []}\n"   
}


function parse_default_params(){
    # input: assoicative array with R arguments-values of general inputs
    # output: assoicative array with R arguments-values of inputs and parameter defaults
    
    local -n arr=${1:-R_args}
    local -n param_arr=${2:-PARAM_AR}
    for param in ${!param_arr[@]}; do
        arr["$param"]="${param_arr[$param]}"
    done

}